
REM ----------------------------------------------------------------------------------------------------------->>
REM   OPEN PANZER BOOTLOADER FLASHING SCRIPT
REM 
REM   This will burn a bootloader. First it will set the fuse bits and unlock the bootloader section, then it 
REM   will burn the bootloader and re-lock the bootloader section. 
REM 
REM   You need to specify settings in the first three sections below. 
REM ----------------------------------------------------------------------------------------------------------->>



REM ----------------------------------------------------------------------------------------------------------->>
REM   1. SET YOUR PATHS HERE 
REM
REM ----------------------------------------------------------------------------------------------------------->>
REM   Not having any spaces in the file name will save you infinite heartache. 
REM   You also for sure don't want any parentheses in the file name either, AVRDUDE will croak if it sees those.
REM   Best also not to use any quotation marks! 

REM   Path to avrdude.conf file: 
set conf_file=C:\openpanzer_boot\avrdude\avrdude.conf

REM   Path to avrdude.exe
set avrdude_exe=C:\openpanzer_boot\avrdude\avrdude.exe

REM   Path to bootloader hex
set boot_hex=C:\openpanzer_boot\optcb2560_boot.hex



REM ----------------------------------------------------------------------------------------------------------->>
REM   2. SET YOUR PROGRAMMER TYPE HERE 
REM   
REM ----------------------------------------------------------------------------------------------------------->>
REM   See http://www.nongnu.org/avrdude/user-manual/avrdude_4.html for a list of programmers, or type avrdude -c ?
REM   If using the USBasp, you can also ignore the warning message avrdude will give you about sck. 
REM   We have listed three possibilities here: 
REM     - avrispmkII - The official AVR programmer
REM     - usbasp     - A very popular and inexpensive Chinese programmer
REM     - stk500v2   - You can use this with the Pololu USB AVR Programmer V2: https://www.pololu.com/product/3172
REM   Remove the "REM" before the one you will be using, and make sure "REM" is in front of the two you will not be using

REM set programmer=avrispmkII
REM set programmer=usbasp           
set programmer=stk500v2



REM ----------------------------------------------------------------------------------------------------------->>
REM   3. SET YOUR COM PORT HERE
REM   
REM ----------------------------------------------------------------------------------------------------------->>
REM   Now set the port. If you are using the avrispmkII or the usbasp, you can simply set it to "usb"
REM   If you are using the Pololu programmer you need to specify the specific COM port and number, 
REM   this will be the "Programming Port" shown in the Pololu configuration utility.
REM   Remove the "REM" before the one you will be using, and make sure "REM" is in front of the line you will not be using

REM set port=usb
set port=COM4


REM ----------------------------------------------------------------------------------------------------------->>
REM   DO NOT CHANGE ANYTHING ELSE BELOW. SAVE THE FILE AND EXECUTE.
REM
REM   If the bootloader was successfully loaded, the red LED on the TCB will blink slowly (once per second).
REM   Now you can load the TCB firmware using OP Config and a regular USB cable. 
REM   You will not need to load the bootloader again. 
REM 
REM ----------------------------------------------------------------------------------------------------------->>


REM ----------------------------------------------------------------------------------------------------------->>
REM   FUSES 
REM ----------------------------------------------------------------------------------------------------------->>
set EFUSE=0xFD
set HFUSE=0xDA
set LFUSE=0xF7
set ULOCKF=0x3F
set LOCKF=0x0F


REM ----------------------------------------------------------------------------------------------------------->>
REM - THIS WILL PERFORM THE TASK
REM ----------------------------------------------------------------------------------------------------------->>
REM   The start cmd.exe /k lets us open the command prompt first and then leave it open so we can see if it worked. 
REM   First half: chip erase (-e), unlock boot section, write fuses. Next comes a "+" symbol to add the second half: 
REM   Second half: now we write the bootloader to flash, then finish by locking the boot section.
start "Flash Bootloader" cmd.exe /K "%avrdude_exe% -C %conf_file% -p atmega2560 -c %programmer% -P %port% -v -e -U lock:w:%ULOCKF%:m -U efuse:w:%EFUSE%:m -U hfuse:w:%HFUSE%:m -U lfuse:w:%LFUSE%:m && %avrdude_exe% -C %conf_file% -p atmega2560 -c %programmer% -P %port% -v -U flash:w:%boot_hex%:i -U lock:w:%LOCKF%:m" 


